@@ -37,6 +37,7 @@
 #include <QVBoxLayout>
 #include <QModelIndex>
 #include <QHash>
+#include <QStackedWidget>
 
 class QMenu;
 
@@ -59,6 +60,7 @@ class KRecentFilesAction;
 
 class KateViewManager;
 class KateMwModOnHdDialog;
+class KateQuickOpen;
 
 #include <QtGui/QStackedLayout>
 // Helper layout class to always provide minimum size
@@ -81,7 +83,7 @@ class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBa
 
   public:
     /**
-     * Construct the window and restore it's state from given config if any
+     * Construct the window and restore its state from given config if any
      * @param sconfig session config for this window, 0 if none
      * @param sgroup session config group to use
      */
@@ -110,9 +112,15 @@ class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBa
     {
       return m_dbusObjectPath;
     }
+
     /**
-     * various methodes to get some little info out of this
+     * get a plugin view with identifier \p name.
+     * \param name the plugin's name
+     * \return pointer to the plugin view if a plugin with \p name is loaded and has a view for this mainwindow,
+     *         otherwise null
      */
+    Kate::PluginView *pluginView (const QString &name);
+
   public:
     /** Returns the URL of the current document.
      * anders: I add this for use from the file selector. */
@@ -192,7 +200,6 @@ class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBa
 
     void slotEditToolbars();
     void slotNewToolbarConfig();
-    void slotWindowActivated ();
     void slotUpdateOpenWith();
     void slotOpenDocument(KUrl);
 
@@ -200,6 +207,11 @@ class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBa
     void editKeys();
     void mSlotFixOpenWithMenu();
 
+    /**
+     * Show quick open
+     */
+    void slotQuickOpen ();
+    
     void tipOfTheDay();
 
     /* to update the caption */
@@ -247,7 +259,7 @@ class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBa
   private Q_SLOTS:
     void slotUpdateBottomViewBar();
     void slotUpdateTopViewBar();
-    
+
   private Q_SLOTS:
     void slotDocumentCloseAll();
     void slotDocumentCloseOther();
@@ -261,7 +273,19 @@ class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBa
 
     bool modNotification;
 
-    // management items
+    /**
+     * stacked widget containing the central area, aka view manager, quickopen, ...
+     */
+    QStackedWidget *m_mainStackedWidget;
+    
+    /**
+     * quick open to fast switch documents
+     */
+    KateQuickOpen *m_quickOpen;
+    
+    /**
+     * keeps track of views
+     */
     KateViewManager *m_viewManager;
 
     KRecentFilesAction *fileOpenRecent;
@@ -270,7 +294,7 @@ class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBa
 
     KToggleAction* settingsShowFileselector;
 
-    bool m_modignore, m_grrr;
+    bool m_modignore;
 
     QString m_dbusObjectPath;
 
@@ -308,8 +332,10 @@ class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBa
     static KateMwModOnHdDialog *s_modOnHdDialog;
 
   public Q_SLOTS:
-    void showPluginConfigPage(Kate::PluginConfigPageInterface *configpageinterface,uint id);  
+    void showPluginConfigPage(Kate::PluginConfigPageInterface *configpageinterface,uint id);
 
+    void slotWindowActivated ();
+    
   protected:
     virtual bool event( QEvent *e );
 };
