@@ -1,5 +1,5 @@
 /*   Kate search plugin
- * 
+ *
  * Copyright (C) 2011 by Kåre Särs <kare.sars@iki.fi>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,8 +31,10 @@
 #include "ui_search.h"
 #include "ui_results.h"
 
+#include "search_while_typing.h"
 #include "search_open_files.h"
 #include "search_folder.h"
+#include "search_project.h"
 #include "replace_matches.h"
 
 class KateSearchCommand;
@@ -107,6 +109,8 @@ private Q_SLOTS:
     void addMatchMark(KTextEditor::Document* doc, int line, int column, int len);
 
     void searchDone();
+    void searchWhileTypingDone();
+    void indicateMatch(bool hasMatch);
 
     void itemSelected(QTreeWidgetItem *item);
 
@@ -119,6 +123,13 @@ private Q_SLOTS:
 
     void resultTabChanged(int index);
 
+    /**
+     * keep track if the project plugin is alive and if the project file did change
+     */
+    void slotPluginViewCreated (const QString &name, Kate::PluginView *pluginView);
+    void slotPluginViewDeleted (const QString &name, Kate::PluginView *pluginView);
+    void slotProjectFileNameChanged ();
+
 protected:
     bool eventFilter(QObject *obj, QEvent *ev);
 
@@ -131,11 +142,18 @@ private:
     Kate::Application                 *m_kateApp;
     SearchOpenFiles                    m_searchOpenFiles;
     SearchFolder                       m_searchFolder;
+    SearchProject                      m_searchProject;
+    SearchWhileTyping                  m_searchWhileTyping;
     ReplaceMatches                     m_replacer;
     KAction                           *m_matchCase;
     KAction                           *m_useRegExp;
     Results                           *m_curResults;
     QList<KTextEditor::MovingRange*>   m_matchRanges;
+
+    /**
+     * current project plugin view, if any
+     */
+    Kate::PluginView *m_projectPluginView;
 };
 
 class KateSearchCommand : public QObject, public KTextEditor::Command
@@ -150,7 +168,7 @@ Q_SIGNALS:
     void setSearchString(const QString &pattern);
     void startSearch();
     void newTab();
-    
+
     //
     // KTextEditor::Command
     //
