@@ -48,7 +48,7 @@
 #include "ui_modonhdwidget.h"
 #include "ui_textareaappearanceconfigwidget.h"
 #include "ui_bordersappearanceconfigwidget.h"
-#include "ui_cursorconfigwidget.h"
+#include "ui_navigationconfigwidget.h"
 #include "ui_editconfigwidget.h"
 #include "ui_indentationconfigwidget.h"
 #include "ui_completionconfigtab.h"
@@ -350,7 +350,7 @@ KateViInputModeConfigTab::KateViInputModeConfigTab(QWidget *parent)
   connect(ui->chkViStatusBarHide, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(ui->tblNormalModeMappings, SIGNAL(cellChanged(int,int)), this, SLOT(slotChanged()));
   connect(ui->btnAddNewNormal, SIGNAL(clicked()), this, SLOT(addNewNormalModeMappingRow()));
-  connect(ui->btnAddNewNormal, SIGNAL(clicked()), this, SLOT(slogChanged()));
+  connect(ui->btnAddNewNormal, SIGNAL(clicked()), this, SLOT(slotChanged()));
   connect(ui->btnRemoveSelectedNormal, SIGNAL(clicked()), this, SLOT(removeSelectedNormalMappingRow()));
   connect(ui->btnRemoveSelectedNormal, SIGNAL(clicked()), this, SLOT(slotChanged()));
   connect(ui->btnImportNormal, SIGNAL(clicked()), this, SLOT(importNormalMappingRow()));
@@ -412,10 +412,10 @@ void KateViInputModeConfigTab::reload ()
   int i = 0;
   foreach( const QString &f, l ) {
     QTableWidgetItem *from
-      = new QTableWidgetItem( KateViKeyParser::getInstance()->decodeKeySequence( f ) );
+      = new QTableWidgetItem( KateViKeyParser::self()->decodeKeySequence( f ) );
     QString s = KateGlobal::self()->viInputModeGlobal()->getMapping( NormalMode, f );
     QTableWidgetItem *to =
-      new QTableWidgetItem( KateViKeyParser::getInstance()->decodeKeySequence( s ) );
+      new QTableWidgetItem( KateViKeyParser::self()->decodeKeySequence( s ) );
 
     ui->tblNormalModeMappings->setItem(i, 0, from);
     ui->tblNormalModeMappings->setItem(i++, 1, to);
@@ -523,8 +523,8 @@ void KateSpellCheckConfigTab::reload()
 }
 //END KateSpellCheckConfigTab
 
-//BEGIN KateSelectConfigTab
-KateSelectConfigTab::KateSelectConfigTab(QWidget *parent)
+//BEGIN KateNavigationConfigTab
+KateNavigationConfigTab::KateNavigationConfigTab(QWidget *parent)
   : KateConfigPage(parent)
 {
   // This will let us having more separation between this page and
@@ -532,7 +532,7 @@ KateSelectConfigTab::KateSelectConfigTab(QWidget *parent)
   QVBoxLayout *layout = new QVBoxLayout;
   QWidget *newWidget = new QWidget(this);
 
-  ui = new Ui::CursorConfigWidget();
+  ui = new Ui::NavigationConfigWidget();
   ui->setupUi( newWidget );
 
   // What's This? Help is in the ui-files
@@ -543,23 +543,22 @@ KateSelectConfigTab::KateSelectConfigTab(QWidget *parent)
   // after initial reload, connect the stuff for the changed () signal
   //
 
-  connect(ui->rbNormal, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
-  connect(ui->rbPersistent, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
+  connect(ui->cbTextSelectionMode, SIGNAL(currentIndexChanged(int)), this, SLOT(slotChanged()));
   connect(ui->chkSmartHome, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
-  connect(ui->chkWrapCursor, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(ui->chkPagingMovesCursor, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(ui->sbAutoCenterCursor, SIGNAL(valueChanged(int)), this, SLOT(slotChanged()));
+  connect(ui->chkScrollPastEnd, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
 
   layout->addWidget(newWidget);
   setLayout(layout);
 }
 
-KateSelectConfigTab::~KateSelectConfigTab()
+KateNavigationConfigTab::~KateNavigationConfigTab()
 {
   delete ui;
 }
 
-void KateSelectConfigTab::apply ()
+void KateNavigationConfigTab::apply ()
 {
   // nothing changed, no need to apply stuff
   if (!hasChanged())
@@ -570,28 +569,28 @@ void KateSelectConfigTab::apply ()
   KateDocumentConfig::global()->configStart ();
 
   KateDocumentConfig::global()->setSmartHome(ui->chkSmartHome->isChecked());
-  KateDocumentConfig::global()->setWrapCursor(ui->chkWrapCursor->isChecked());
 
   KateViewConfig::global()->setAutoCenterLines(qMax(0, ui->sbAutoCenterCursor->value()));
   KateDocumentConfig::global()->setPageUpDownMovesCursor(ui->chkPagingMovesCursor->isChecked());
 
-  KateViewConfig::global()->setPersistentSelection (ui->rbPersistent->isChecked());
+  KateViewConfig::global()->setPersistentSelection (ui->cbTextSelectionMode->currentIndex() == 1);
+
+  KateViewConfig::global()->setScrollPastEnd(ui->chkScrollPastEnd->isChecked());
 
   KateDocumentConfig::global()->configEnd ();
   KateViewConfig::global()->configEnd ();
 }
 
-void KateSelectConfigTab::reload ()
+void KateNavigationConfigTab::reload ()
 {
-  ui->rbNormal->setChecked( ! KateViewConfig::global()->persistentSelection() );
-  ui->rbPersistent->setChecked( KateViewConfig::global()->persistentSelection() );
+  ui->cbTextSelectionMode->setCurrentIndex( KateViewConfig::global()->persistentSelection() ? 1 : 0 );
 
   ui->chkSmartHome->setChecked(KateDocumentConfig::global()->smartHome());
-  ui->chkWrapCursor->setChecked(KateDocumentConfig::global()->wrapCursor());
   ui->chkPagingMovesCursor->setChecked(KateDocumentConfig::global()->pageUpDownMovesCursor());
   ui->sbAutoCenterCursor->setValue(KateViewConfig::global()->autoCenterLines());
+  ui->chkScrollPastEnd->setChecked(KateViewConfig::global()->scrollPastEnd());
 }
-//END KateSelectConfigTab
+//END KateNavigationConfigTab
 
 //BEGIN KateEditGeneralConfigTab
 KateEditGeneralConfigTab::KateEditGeneralConfigTab(QWidget *parent)
@@ -607,10 +606,7 @@ KateEditGeneralConfigTab::KateEditGeneralConfigTab(QWidget *parent)
   connect(ui->chkStaticWordWrap, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(ui->chkShowStaticWordWrapMarker, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(ui->sbWordWrap, SIGNAL(valueChanged(int)), this, SLOT(slotChanged()));
-  connect( ui->chkRemoveTrailingSpaces, SIGNAL(toggled(bool)), this, SLOT(slotChanged()) );
-  connect(ui->chkAutoBrackets, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(ui->chkSmartCopyCut, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
-  connect(ui->chkScrollPastEnd, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
 
   // "What's this?" help is in the ui-file
 
@@ -633,9 +629,6 @@ void KateEditGeneralConfigTab::apply ()
   KateViewConfig::global()->configStart ();
   KateDocumentConfig::global()->configStart ();
 
-  KateDocumentConfig::global()->setAutoBrackets(ui->chkAutoBrackets->isChecked());
-  KateDocumentConfig::global()->setRemoveTrailingDyn(ui->chkRemoveTrailingSpaces->isChecked());
-
   KateDocumentConfig::global()->setWordWrapAt(ui->sbWordWrap->value());
   KateDocumentConfig::global()->setWordWrap(ui->chkStaticWordWrap->isChecked());
 
@@ -643,7 +636,6 @@ void KateEditGeneralConfigTab::apply ()
 
   KateDocumentConfig::global()->configEnd ();
   KateViewConfig::global()->setSmartCopyCut(ui->chkSmartCopyCut->isChecked());
-  KateViewConfig::global()->setScrollPastEnd(ui->chkScrollPastEnd->isChecked());
   KateViewConfig::global()->configEnd ();
 }
 
@@ -653,10 +645,7 @@ void KateEditGeneralConfigTab::reload ()
   ui->chkShowStaticWordWrapMarker->setChecked( KateRendererConfig::global()->wordWrapMarker() );
   ui->sbWordWrap->setSuffix(ki18ncp("Wrap words at", " character", " characters"));
   ui->sbWordWrap->setValue( KateDocumentConfig::global()->wordWrapAt() );
-  ui->chkRemoveTrailingSpaces->setChecked( KateDocumentConfig::global()->removeTrailingDyn() );
-  ui->chkAutoBrackets->setChecked( KateDocumentConfig::global()->autoBrackets() );
   ui->chkSmartCopyCut->setChecked( KateViewConfig::global()->smartCopyCut() );
-  ui->chkScrollPastEnd->setChecked( KateViewConfig::global()->scrollPastEnd() );
 }
 //END KateEditGeneralConfigTab
 
@@ -665,7 +654,7 @@ void KateEditGeneralConfigTab::reload ()
 KateEditConfigTab::KateEditConfigTab(QWidget *parent)
   : KateConfigPage(parent)
   , editConfigTab(new KateEditGeneralConfigTab(this))
-  , selectConfigTab(new KateSelectConfigTab(this))
+  , navigationConfigTab(new KateNavigationConfigTab(this))
   , indentConfigTab(new KateIndentConfigTab(this))
   , completionConfigTab (new KateCompletionConfigTab(this))
   , viInputModeConfigTab(new KateViInputModeConfigTab(this))
@@ -677,14 +666,14 @@ KateEditConfigTab::KateEditConfigTab(QWidget *parent)
 
   // add all tabs
   tabWidget->insertTab(0, editConfigTab, i18n("General"));
-  tabWidget->insertTab(1, selectConfigTab, i18n("Cursor && Selection"));
+  tabWidget->insertTab(1, navigationConfigTab, i18n("Text Navigation"));
   tabWidget->insertTab(2, indentConfigTab, i18n("Indentation"));
   tabWidget->insertTab(3, completionConfigTab, i18n("Auto Completion"));
   tabWidget->insertTab(4, viInputModeConfigTab, i18n("Vi Input Mode"));
   tabWidget->insertTab(5, spellCheckConfigTab, i18n("Spellcheck"));
 
   connect(editConfigTab, SIGNAL(changed()), this, SLOT(slotChanged()));
-  connect(selectConfigTab, SIGNAL(changed()), this, SLOT(slotChanged()));
+  connect(navigationConfigTab, SIGNAL(changed()), this, SLOT(slotChanged()));
   connect(indentConfigTab, SIGNAL(changed()), this, SLOT(slotChanged()));
   connect(completionConfigTab, SIGNAL(changed()), this, SLOT(slotChanged()));
   connect(viInputModeConfigTab, SIGNAL(changed()), this, SLOT(slotChanged()));
@@ -702,7 +691,7 @@ void KateEditConfigTab::apply ()
 {
   // try to update the rest of tabs
   editConfigTab->apply();
-  selectConfigTab->apply();
+  navigationConfigTab->apply();
   indentConfigTab->apply();
   completionConfigTab->apply();
   viInputModeConfigTab->apply();
@@ -712,7 +701,7 @@ void KateEditConfigTab::apply ()
 void KateEditConfigTab::reload ()
 {
   editConfigTab->reload();
-  selectConfigTab->reload();
+  navigationConfigTab->reload();
   indentConfigTab->reload();
   completionConfigTab->reload();
   viInputModeConfigTab->reload();
@@ -722,7 +711,7 @@ void KateEditConfigTab::reload ()
 void KateEditConfigTab::reset ()
 {
   editConfigTab->reset();
-  selectConfigTab->reset();
+  navigationConfigTab->reset();
   indentConfigTab->reset();
   completionConfigTab->reset();
   viInputModeConfigTab->reset();
@@ -732,7 +721,7 @@ void KateEditConfigTab::reset ()
 void KateEditConfigTab::defaults ()
 {
   editConfigTab->defaults();
-  selectConfigTab->defaults();
+  navigationConfigTab->defaults();
   indentConfigTab->defaults();
   completionConfigTab->defaults();
   viInputModeConfigTab->defaults();
@@ -789,6 +778,10 @@ KateViewDefaultsConfig::KateViewDefaultsConfig(QWidget *parent)
 
   connect(bordersUi->chkIconBorder, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(bordersUi->chkScrollbarMarks, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
+  connect(bordersUi->chkScrollbarMiniMap, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
+  connect(bordersUi->chkScrollbarMiniMapAll, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
+  bordersUi->chkScrollbarMiniMapAll->hide(); // this is temporary until the feature is done
+  connect(bordersUi->spBoxMiniMapWidth, SIGNAL(valueChanged(int)), this, SLOT(slotChanged()));
   connect(bordersUi->chkLineNumbers, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(bordersUi->chkShowLineModification, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(bordersUi->chkShowFoldingMarkers, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
@@ -820,6 +813,9 @@ void KateViewDefaultsConfig::apply ()
   KateViewConfig::global()->setLineNumbers (bordersUi->chkLineNumbers->isChecked());
   KateViewConfig::global()->setIconBar (bordersUi->chkIconBorder->isChecked());
   KateViewConfig::global()->setScrollBarMarks (bordersUi->chkScrollbarMarks->isChecked());
+  KateViewConfig::global()->setScrollBarMiniMap (bordersUi->chkScrollbarMiniMap->isChecked());
+  KateViewConfig::global()->setScrollBarMiniMapAll (bordersUi->chkScrollbarMiniMapAll->isChecked());
+  KateViewConfig::global()->setScrollBarMiniMapWidth (bordersUi->spBoxMiniMapWidth->value());
   KateViewConfig::global()->setFoldingBar (bordersUi->chkShowFoldingMarkers->isChecked());
   KateViewConfig::global()->setLineModification(bordersUi->chkShowLineModification->isChecked());
 
@@ -853,6 +849,9 @@ void KateViewDefaultsConfig::reload ()
   bordersUi->chkLineNumbers->setChecked(KateViewConfig::global()->lineNumbers());
   bordersUi->chkIconBorder->setChecked(KateViewConfig::global()->iconBar());
   bordersUi->chkScrollbarMarks->setChecked(KateViewConfig::global()->scrollBarMarks());
+  bordersUi->chkScrollbarMiniMap->setChecked(KateViewConfig::global()->scrollBarMiniMap());
+  bordersUi->chkScrollbarMiniMapAll->setChecked(KateViewConfig::global()->scrollBarMiniMapAll());
+  bordersUi->spBoxMiniMapWidth->setValue(KateViewConfig::global()->scrollBarMiniMapWidth());
   bordersUi->chkShowFoldingMarkers->setChecked(KateViewConfig::global()->foldingBar());
   bordersUi->chkShowLineModification->setChecked(KateViewConfig::global()->lineModification());
   bordersUi->rbSortBookmarksByPosition->setChecked(KateViewConfig::global()->bookmarkSort()==0);
@@ -905,7 +904,7 @@ KateSaveConfigTab::KateSaveConfigTab( QWidget *parent )
   connect( ui->chkDetectEOL, SIGNAL(toggled(bool)), this, SLOT(slotChanged()) );
   connect( ui->chkEnableBOM, SIGNAL(toggled(bool)), this, SLOT(slotChanged()) );
   connect( ui->lineLengthLimit, SIGNAL(valueChanged(int)), this, SLOT(slotChanged()));
-  connect( ui->chkRemoveTrailingSpaces, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
+  connect( ui->cbRemoveTrailingSpaces, SIGNAL(currentIndexChanged(int)), this, SLOT(slotChanged()));
   connect( ui->chkNewLineAtEof, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect( uiadv->chkBackupLocalFiles, SIGNAL(toggled(bool)), this, SLOT(slotChanged()) );
   connect( uiadv->chkBackupRemoteFiles, SIGNAL(toggled(bool)), this, SLOT(slotChanged()) );
@@ -970,7 +969,7 @@ void KateSaveConfigTab::apply()
 
   KateDocumentConfig::global()->setSearchDirConfigDepth(uiadv->sbConfigFileSearchDepth->value());
 
-  KateDocumentConfig::global()->setRemoveSpaces(ui->chkRemoveTrailingSpaces->isChecked());
+  KateDocumentConfig::global()->setRemoveSpaces(ui->cbRemoveTrailingSpaces->currentIndex());
 
   KateDocumentConfig::global()->setNewLineAtEof(ui->chkNewLineAtEof->isChecked());
 
@@ -983,7 +982,7 @@ void KateSaveConfigTab::apply()
   KateDocumentConfig::global()->setEol(ui->cmbEOL->currentIndex());
   KateDocumentConfig::global()->setAllowEolDetection(ui->chkDetectEOL->isChecked());
   KateDocumentConfig::global()->setBom(ui->chkEnableBOM->isChecked());
-  
+
   KateDocumentConfig::global()->setLineLengthLimit(ui->lineLengthLimit->value());
 
   KateDocumentConfig::global()->configEnd ();
@@ -1046,7 +1045,7 @@ void KateSaveConfigTab::reload()
   ui->chkEnableBOM->setChecked(KateDocumentConfig::global()->bom());
   ui->lineLengthLimit->setValue(KateDocumentConfig::global()->lineLengthLimit());
 
-  ui->chkRemoveTrailingSpaces->setChecked(KateDocumentConfig::global()->removeSpaces());
+  ui->cbRemoveTrailingSpaces->setCurrentIndex(KateDocumentConfig::global()->removeSpaces());
   ui->chkNewLineAtEof->setChecked(KateDocumentConfig::global()->newLineAtEof());
   uiadv->sbConfigFileSearchDepth->setValue(KateDocumentConfig::global()->searchDirConfigDepth());
 
@@ -1068,6 +1067,8 @@ void KateSaveConfigTab::defaults()
 {
   modeConfigPage->defaults();
 
+  ui->cbRemoveTrailingSpaces->setCurrentIndex(0);
+
   uiadv->chkBackupLocalFiles->setChecked( true );
   uiadv->chkBackupRemoteFiles->setChecked( false );
   uiadv->edtBackupPrefix->setText( "" );
@@ -1419,25 +1420,29 @@ KateModOnHdPrompt::KateModOnHdPrompt( KateDocument *doc,
 {
   setButtons( Ok | Apply | Cancel | User1 );
 
-  QString title, btnOK, whatisok;
+  QString title, okText, okIcon, okToolTip;
   if ( modtype == KTextEditor::ModificationInterface::OnDiskDeleted )
   {
     title = i18n("File Was Deleted on Disk");
-    btnOK = i18n("&Save File As...");
-    whatisok = i18n("Lets you select a location and save the file again.");
+    okText = i18n("&Save File As...");
+    okIcon = "document-save-as";
+    okToolTip = i18n("Lets you select a location and save the file again.");
   } else {
     title = i18n("File Changed on Disk");
-    btnOK = i18n("&Reload File");
-    whatisok = i18n("Reload the file from disk. If you have unsaved changes, "
+    okText = i18n("&Reload File");
+    okIcon = "view-refresh";
+    okToolTip = i18n("Reload the file from disk. If you have unsaved changes, "
         "they will be lost.");
   }
 
-  setButtonText( Ok, btnOK );
-  setButtonText( Apply, i18n("&Ignore") );
+  setButtonText( Ok, okText );
+  setButtonIcon( Ok, KIcon( okIcon ) );
+  setButtonText( Apply, i18n("&Ignore Changes") );
+  setButtonIcon( Apply, KIcon( "dialog-warning" ) );
 
-  setButtonWhatsThis( Ok, whatisok );
-  setButtonWhatsThis( Apply, i18n("Ignore the changes. You will not be prompted again.") );
-  setButtonWhatsThis( Cancel, i18n("Do nothing. Next time you focus the file, "
+  setButtonToolTip( Ok, okToolTip );
+  setButtonToolTip( Apply, i18n("Ignore the changes. You will not be prompted again.") );
+  setButtonToolTip( Cancel, i18n("Do nothing. Next time you focus the file, "
       "or try to save it or close it, you will be prompted again.") );
 
   setCaption( title );
@@ -1453,8 +1458,8 @@ KateModOnHdPrompt::KateModOnHdPrompt( KateDocument *doc,
   // If the file isn't deleted, present a diff button, and a overwrite action.
   if ( modtype != KTextEditor::ModificationInterface::OnDiskDeleted )
   {
-    setButtonText( User1, i18n("Overwrite") );
-    setButtonWhatsThis( User1, i18n("Overwrite the disk file with the editor content.") );
+    setButtonGuiItem( User1, KStandardGuiItem::overwrite() );
+    setButtonToolTip( User1, i18n("Overwrite the disk file with the editor content.") );
     connect( ui->btnDiff, SIGNAL(clicked()), this, SLOT(slotDiff()) );
   }
   else
