@@ -24,15 +24,20 @@
 #include "kateswapfile.h"
 #include "kateview.h"
 #include "kateconfig.h"
+#include "kateswapdiffcreator.h"
 
 #include <kde_file.h>
+#include <klocale.h>
+#include <kicon.h>
+#include <kstandardguiitem.h>
 
 #include <QFileInfo>
 #include <QDir>
 #include <QApplication>
 
+
 // swap file version header
-const static char * const swapFileVersionString = "Kate Swap File - Version 1.0";
+const static char * const swapFileVersionString = "Kate Swap File 2.0";
 
 // tokens for swap files
 const static qint8 EA_StartEditing  = 'S';
@@ -51,7 +56,7 @@ SwapFile::SwapFile(KateDocument *document)
   , m_document(document)
   , m_trackingEnabled(false)
   , m_recovered(false)
-  , m_modified(false)
+  , m_needSync(false)
 {
   // fixed version of serialisation
   m_stream.setVersion (QDataStream::Qt_4_6);
@@ -64,7 +69,8 @@ SwapFile::SwapFile(KateDocument *document)
   connect(&m_document->buffer(), SIGNAL(loaded(QString,bool)), this, SLOT(fileLoaded(QString)));
   connect(m_document, SIGNAL(configChanged()), this, SLOT(configChanged()));
 
-  configChanged();
+  // tracking on!
+  setTrackingEnabled (true);
 }
 
 SwapFile::~SwapFile()
@@ -77,7 +83,6 @@ SwapFile::~SwapFile()
 
 void SwapFile::configChanged()
 {
-  setTrackingEnabled(!m_document->config()->swapFileNoSync());
 }
 
 void SwapFile::setTrackingEnabled(bool enable)
@@ -93,6 +98,7 @@ void SwapFile::setTrackingEnabled(bool enable)
   if (m_trackingEnabled) {
     connect(&buffer, SIGNAL(editingStarted()), this, SLOT(startEditing()));
     connect(&buffer, SIGNAL(editingFinished()), this, SLOT(finishEditing()));
+    connect(m_document, SIGNAL(modifiedChanged(KTextEditor::Document*)), this, SLOT(modifiedChanged()));
 
     connect(&buffer, SIGNAL(lineWrapped(KTextEditor::Cursor)), this, SLOT(wrapLine(KTextEditor::Cursor)));
     connect(&buffer, SIGNAL(lineUnwrapped(int)), this, SLOT(unwrapLine(int)));
@@ -101,6 +107,7 @@ void SwapFile::setTrackingEnabled(bool enable)
   } else {
     disconnect(&buffer, SIGNAL(editingStarted()), this, SLOT(startEditing()));
     disconnect(&buffer, SIGNAL(editingFinished()), this, SLOT(finishEditing()));
+    disconnect(m_document, SIGNAL(modifiedChanged(KTextEditor::Document*)), this, SLOT(modifiedChanged()));
 
     disconnect(&buffer, SIGNAL(lineWrapped(KTextEditor::Cursor)), this, SLOT(wrapLine(KTextEditor::Cursor)));
     disconnect(&buffer, SIGNAL(lineUnwrapped(int)), this, SLOT(unwrapLine(int)));
@@ -116,13 +123,40 @@ void SwapFile::fileClosed ()
     removeSwapFile();
   } else {
     m_document->setReadWrite(true);
-    emit swapFileHandled();
   }
 
   // purge filename
   updateFileName();
 }
 
+KateDocument* SwapFile::document()
+{
+  return m_document;
+}
+
+bool SwapFile::isValidSwapFile(QDataStream& stream, bool checkDigest) const
+{
+  // read and check header
+  QByteArray header;
+  stream >> header;
+
+  if (header != swapFileVersionString) {
+    kWarning( 13020 ) << "Can't open swap file, wrong version";
+    return false;
+  }
+
+  // read md5 digest
+  QByteArray digest;
+  stream >> digest;
+//   kDebug() << "DIGEST:" << digest << m_document->digest();
+  if (checkDigest && digest != m_document->digest()) {
+    kWarning( 13020 ) << "Can't recover from swap file, digest of document has changed";
+    return false;
+  }
+
+  return true;
+}
+
 void SwapFile::fileLoaded(const QString&)
 {
   // look for swap file
@@ -141,9 +175,32 @@ void SwapFile::fileLoaded(const QString&)
     return;
   }
 
-  // emit signal in case the document has more views
+  // sanity check
+  QFile peekFile(fileName());
+  if (peekFile.open(QIODevice::ReadOnly)) {
+    QDataStream stream(&peekFile);
+    if (!isValidSwapFile(stream, true)) {
+      removeSwapFile();
+      return;
+    }
+    peekFile.close();
+  } else {
+    kWarning( 13020 ) << "Can't open swap file:" << fileName();
+    return;
+  }
+
+  // show swap file message
   m_document->setReadWrite(false);
-  emit swapFileFound();
+  showSwapFileMessage();
+}
+
+void SwapFile::modifiedChanged()
+{
+  if (!m_document->isModified() && !shouldRecover()) {
+    m_needSync = false;
+    // the file is not modified and we are not in recover mode
+    removeSwapFile();
+  }
 }
 
 void SwapFile::recover()
@@ -157,7 +214,6 @@ void SwapFile::recover()
   if (m_swapfile.isOpen()) {
     kWarning( 13020 ) << "Attempt to recover an already modified document. Aborting";
     removeSwapFile();
-    emit swapFileBroken();
     return;
   }
 
@@ -165,7 +221,6 @@ void SwapFile::recover()
   if (!m_swapfile.open(QIODevice::ReadOnly))
   {
     kWarning( 13020 ) << "Can't open swap file";
-    emit swapFileHandled();
     return;
   }
 
@@ -182,25 +237,18 @@ void SwapFile::recover()
   m_stream.setDevice(0);
   m_swapfile.close();
 
-  if (success) {
-    // emit signal in case the document has more views
-    emit swapFileHandled();
-  } else {
+  if (!success)
     removeSwapFile();
-    emit swapFileBroken();
-  }
+
+  // recover can also be called through the KTE::RecoveryInterface.
+  // Make sure, the message is hidden in this case as well.
+  if (m_swapMessage)
+    m_swapMessage->deleteLater();
 }
 
-bool SwapFile::recover(QDataStream& stream)
-{  
-  // read and check header
-  QByteArray header;
-  stream >> header;
-  if (header != swapFileVersionString)
-  {
-    stream.setDevice (0);
-    m_swapfile.close ();
-    kWarning( 13020 ) << "Can't open swap file, wrong version";
+bool SwapFile::recover(QDataStream& stream, bool checkDigest)
+{
+  if (!isValidSwapFile(stream, checkDigest)) {
     return false;
   }
 
@@ -294,7 +342,6 @@ bool SwapFile::recover(QDataStream& stream)
   // warn the user if the swap file is not complete
   if (brokenSwapFile) {
     kWarning ( 13020 ) << "Some data might be lost";
-    emit swapFileBroken();
   }
   
   // reconnect the signals
@@ -305,7 +352,7 @@ bool SwapFile::recover(QDataStream& stream)
 
 void SwapFile::fileSaved(const QString&)
 {
-  m_modified = false;
+  m_needSync = false;
   
   // remove old swap file (e.g. if a file A was "saved as" B)
   removeSwapFile();
@@ -330,6 +377,9 @@ void SwapFile::startEditing ()
 
     // write file header
     m_stream << QByteArray (swapFileVersionString);
+    
+    // write md5 digest
+    m_stream << m_document->digest ();
   } else if (m_stream.device() == 0) {
     m_swapfile.open(QIODevice::Append);
     m_stream.setDevice(&m_swapfile);
@@ -346,7 +396,8 @@ void SwapFile::finishEditing ()
     return;
 
   // write the file to the disk every 15 seconds
-  if (!syncTimer()->isActive())
+  // skip this if we disabled forced syncing 
+  if (!m_document->config()->swapFileNoSync() && !syncTimer()->isActive())
     syncTimer()->start(15000);
   
   // format: qint8
@@ -363,7 +414,7 @@ void SwapFile::wrapLine (const KTextEditor::Cursor &position)
   // format: qint8, int, int
   m_stream << EA_WrapLine << position.line() << position.column();
 
-  m_modified = true;
+  m_needSync = true;
 }
 
 void SwapFile::unwrapLine (int line)
@@ -375,7 +426,7 @@ void SwapFile::unwrapLine (int line)
   // format: qint8, int
   m_stream << EA_UnwrapLine << line;
 
-  m_modified = true;
+  m_needSync = true;
 }
 
 void SwapFile::insertText (const KTextEditor::Cursor &position, const QString &text)
@@ -387,7 +438,7 @@ void SwapFile::insertText (const KTextEditor::Cursor &position, const QString &t
   // format: qint8, int, int, bytearray
   m_stream << EA_InsertText << position.line() << position.column() << text.toUtf8 ();
 
-  m_modified = true;
+  m_needSync = true;
 }
 
 void SwapFile::removeText (const KTextEditor::Range &range)
@@ -402,7 +453,7 @@ void SwapFile::removeText (const KTextEditor::Range &range)
             << range.start().line() << range.start().column()
             << range.end().column();
 
-  m_modified = true;
+  m_needSync = true;
 }
 
 bool SwapFile::shouldRecover() const
@@ -418,7 +469,11 @@ void SwapFile::discard()
 {
   m_document->setReadWrite(true);
   removeSwapFile();
-  emit swapFileHandled();
+
+  // discard can also be called through the KTE::RecoveryInterface.
+  // Make sure, the message is hidden in this case as well.
+  if (m_swapMessage)
+    m_swapMessage->deleteLater();
 }
 
 void SwapFile::removeSwapFile()
@@ -470,8 +525,8 @@ QTimer* SwapFile::syncTimer()
 
 void SwapFile::writeFileToDisk()
 {
-  if (m_modified) {
-    m_modified = false;
+  if (m_needSync) {
+    m_needSync = false;
 
     #ifndef Q_OS_WIN
     // ensure that the file is written to disk
@@ -484,6 +539,34 @@ void SwapFile::writeFileToDisk()
   }
 }
 
+void SwapFile::showSwapFileMessage()
+{
+  m_swapMessage = new KTextEditor::Message(KTextEditor::Message::Warning,
+    i18n("The file was not closed properly."));
+  m_swapMessage->setWordWrap(true);
+
+  QAction* diffAction = new QAction(KIcon("split"), i18n("View Changes"), 0);
+  QAction* recoverAction = new QAction(KIcon("edit-redo"), i18n("Recover Data"), 0);
+  QAction* discardAction = new QAction(KStandardGuiItem::discard().icon(), i18n("Discard"), 0);
+
+  m_swapMessage->addAction(diffAction, false);
+  m_swapMessage->addAction(recoverAction);
+  m_swapMessage->addAction(discardAction);
+
+  connect(diffAction, SIGNAL(triggered()), SLOT(showDiff()));
+  connect(recoverAction, SIGNAL(triggered()), SLOT(recover()), Qt::QueuedConnection);
+  connect(discardAction, SIGNAL(triggered()), SLOT(discard()), Qt::QueuedConnection);
+
+  m_document->postMessage(m_swapMessage);
+}
+
+void SwapFile::showDiff()
+{
+  // the diff creator deletes itself thorugh deleteLater() when it's done
+  SwapDiffCreator* diffCreator = new SwapDiffCreator(this);
+  diffCreator->viewDiff();
+}
+
 }
 
 // kate: space-indent on; indent-width 2; replace-tabs on;
